#
# spec file for package ghc-async
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name async
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.1.1
Release:        3.1
Summary:        Run IO operations asynchronously and wait for their results
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
%endif

%description
This package provides a higher-level interface over threads, in which an 'Async
a' is a concurrent thread that will eventually deliver a value of type 'a'.
The package provides ways to create 'Async' computations, wait for their
results, and cancel them.

Using 'Async' is safer than using threads in two ways:

* When waiting for a thread to return a result, if the thread dies with an
exception then the caller must either re-throw the exception ('wait') or handle
it ('waitCatch'); the exception cannot be ignored.

* The API makes it possible to build a tree of threads that are automatically
killed when their parent dies (see 'withAsync').

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc changelog.md

%changelog
* Tue Nov 22 2016 psimons@suse.com
- Update to version 2.1.1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.1.0 revision 0 with cabal2obs.
* Sun Jan 24 2016 mimi.vx@gmail.com
- update to 2.1.0
  * Bump base dependency to allow 4.10
  * Remove invalid Monad instance for Concurrently
  * Add Monoid and Semigroup instances for Concurrently
  * Add forConcurrently (flipped version of mapConcurrently)
  * Add STM version of all applicable IO functions: waitAnySTM, waitAnyCatchSTM,
  waitEitherSTM, waitEitherCatchSTM, waitEitherSTM_, and waitBothSTM.
* Mon Apr 13 2015 mimi.vx@gmail.com
- update to 2.0.2
  * Add a Monad instance for Concurrently * Bump base dependency to allow 4.9
  * Add workaround to waitCatch for #14
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 2.0.1.5
  * update dependency for ghc 7.8
  * for Haskell Platform 2014.2.0.0
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm 0.8.6
  * require exact version of ghc-compiler
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.0.1.4 from upstream
  * fix in test suite
- version required for Haskell Platform 2013.2
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Wed Jan  2 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- Initial package generated by cabal2spec
